@@ -5,10 +5,12 @@ from typing import Generator
 
 from pytest import fixture  # type: ignore
 
+root = Path(".").absolute()
+
 
 @fixture
 def in_sandbox() -> Generator:
-    sandbox_dir = Path("/tmp") / "sandbox"
+    sandbox_dir = root / "sandbox"
     if sandbox_dir.exists():
         shutil.rmtree(str(sandbox_dir))
 
